pygeodesy.solveBase

Package pygeodesy :: Module solveBase |
[frames] | no frames]

# Module solveBase

(INTERNAL) Private base classes for pygeodesy.geodsolve and pygeodesy.rhumb.solve.

Version: 25.12.06

Classes
| _SolveCapsBase (NTERNAL) Base class for `_SolveBase` and `_LineSolveBase`.
| _SolveBase (INTERNAL) Base class for `_SolveBase` and `_SolveLineBase`.
| _SolveGDictBase (NTERNAL) Base class for `_GeodesicSolveBase` and `_RhumbSolveBase`.
| _SolveGDictLineBase (NTERNAL) Base class for `GeodesicLineSolve` and `RhumbLineSolve`.

Variables
| __all__ = `_ALL_LAZY.solveBase`